OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Ετικέτες",
    "Update" : "Ενημέρωση",
    "Create" : "Δημιουργία",
    "Select tag…" : "Επιλογή ετικέτας ...",
    "Added system tag {systemtag}" : "Προστέθηκε σύστημα ετικετών {systemtag}",
    "Added system tag %1$s" : "Προστέθηκε σύστημα ετικετών %1$s",
    "%1$s added system tag %2$s" : "%1$s προστέθηκε σύστημα ετικετών %2$s",
    "{actor} added system tag {systemtag}" : "{actor} προστέθηκε σύστημα ετικετών {systemtag}",
    "Removed system tag {systemtag}" : "Αφαιρέθηκε ετικέτα συστήματος {systemtag}",
    "Removed system tag %1$s" : "Αφαιρέθηκε ετικέτα συστήματος %1$s",
    "%1$s removed system tag %2$s" : "%1$s Αφαίρεσε ετικέτα συστήματος %2$s",
    "{actor} removed system tag {systemtag}" : "{actor} αφαίρεσε ετικέτα συστήματος {systemtag}",
    "You created system tag %1$s" : "Δημιουργήσατε ετικέτα συστήματος %1$s",
    "You created system tag {systemtag}" : "Δημιουργήσατε ετικέτα συστήματος {systemtag}",
    "%1$s created system tag %2$s" : "%1$s δημιούργησε ετικέτα συστήματος %2$s",
    "{actor} created system tag {systemtag}" : "{actor} δημιούργησε ετικέτα συστήματος {systemtag}",
    "You deleted system tag %1$s" : "Αφαιρέσατε ετικέτα συστήματος %1$s",
    "You deleted system tag {systemtag}" : "Αφαιρέσατε ετικέτα συστήματος {systemtag}",
    "%1$s deleted system tag %2$s" : "%1$s αφαίρεσε ετικέτα συστήματος %2$s",
    "{actor} deleted system tag {systemtag}" : "{actor} αφαίρεσε ετικέτα συστήματος {systemtag}",
    "You updated system tag %2$s to %1$s" : "Ενημερώσατε ετικέτα συστήματος %2$s σε %1$s",
    "You updated system tag {oldsystemtag} to {newsystemtag}" : "Ενημερώσατε ετικέτα συστήματος {oldsystemtag} σε {newsystemtag}",
    "%1$s updated system tag %3$s to %2$s" : "%1$s ενημέρωσε ετικέτα συστήματος %3$s ζε %2$s",
    "{actor} updated system tag {oldsystemtag} to {newsystemtag}" : "{actor} ενημέρωσε ετικέτα συστήματος {oldsystemtag} σε {newsystemtag}",
    "You added system tag %2$s to %1$s" : "Προσθέσατε ετικέτα συστήματος %2$s στο %1$s",
    "You added system tag {systemtag} to {file}" : "Προσθέσατε ετικέτα συστήματος {systemtag} στο {file}",
    "%1$s added system tag %3$s to %2$s" : "%1$s πρόσθεσε ετικέτα συστήματος %3$s στο %2$s",
    "{actor} added system tag {systemtag} to {file}" : "{actor} πρόσθεσε ετικέτα συστήματος {systemtag} στο {file}",
    "You removed system tag %2$s from %1$s" : "Αφαιρέσατε ετικέτα συστήματος %2$s από %1$s",
    "You removed system tag {systemtag} from {file}" : "Αφαιρέσατε ετικέτα συστήματος {systemtag} από {file}",
    "%1$s removed system tag %3$s from %2$s" : "%1$s αφαίρεσε ετικέτα συστήματος %3$s από %2$s",
    "{actor} removed system tag {systemtag} from {file}" : "{actor} αφαίρεσε ετικέτα συστήματος {systemtag} από {file}",
    "%s (restricted)" : "%s (περιορισμένο)",
    "%s (invisible)" : "%s (αόρατο)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Οι ετικέτες συστήματος</strong> για ένα αρχείο έχουν τροποποιηθεί",
    "Collaborative tags" : "Ετικέτες συνεργασίας",
    "Tagged files" : "Αρχεία με ετικέτες",
    "Select tags to filter by" : "Επιλογή ετικετών για φιλτράρισμα με",
    "No tags found" : "Δεν βρέθηκαν ετικέτες",
    "Please select tags to filter by" : "Παρακαλώ επιλέξτε ετικέτες για να φιλτραριστούν με",
    "No files found for the selected tags" : "Δεν βρέθηκαν αρχεία για τις επιλεγμένες ετικέτες",
    "Select tag …" : "Επιλογή ετικέτας ...",
    "Create a new tag" : "Δημιούργησε νέα ετικέτα",
    "Name" : "Όνομα",
    "Public" : "Δημόσιο",
    "Restricted" : "Περιορισμένο",
    "Invisible" : "Αόρατο",
    "Delete" : "Διαγραφή",
    "Reset" : "Επαναφορά",
    "No files in here" : "Δεν υπάρχουν αρχεία",
    "No entries found in this folder" : "Δεν βρέθηκαν καταχωρήσεις σε αυτόν το φάκελο",
    "Size" : "Μέγεθος",
    "Modified" : "Τροποποιήθηκε"
},
"nplurals=2; plural=(n != 1);");
